@@ -1,12 +1,12 @@
 import os
 import datetime
+import shutil
 
 
 class NameNotSpecificationError(Exception):
     def __init__(self, name):
         super()
         self.name = name
-        self.__str__()
 
     def __str__(self):
         return 'The name {} does not meet the specification'.format(self.name)
@@ -16,7 +16,6 @@ class PathNotFoundError(Exception):
     def __init__(self):
         super()
         # self.name = name
-        self.__str__()
 
     def __str__(self):
         return 'path is not found'
@@ -26,15 +25,22 @@ class PathNotFoundError(Exception):
     def __init__(self, name):
         super()
         self.name = name
-        self.__str__()
 
     def __str__(self):
         return '{} is not found'.format(self.name)
 
 
 class create(object):
-    def __init__(self, **kw):
-        super(create)
+    def __init__(self, *new, entry_points='""', **kw):
+        '''
+        Params:
+        entry_points:Not required:dict
+        *new:tuple
+            standard:((new_element,element_content),...)
+        **kw:any
+            required:path,dirName,pkgName,author,author_email,description,url,project_urls,classifiers,python_requires,install_requires
+        '''
+        super(create, self)
         try:
             kw['path']
         except KeyError:
@@ -116,9 +122,9 @@ requires = [
 build-backend = "setuptools.build_meta"        
         ''')
         print('INFO[001] create the README.md file')
-        self.createFile('./'+d+'/', 'README.md', '''#your project readme''')
+        self.createFile('./'+d+'/', 'README.md', '''# your project readme''')
         print('INFO[002] create the setup.py file')
-        self.createFile('./'+d+'/', 'setup.py', '''
+        setup = '''
 import setuptools
 
 with open("README.md", "r", encoding="utf-8") as fh:
@@ -135,14 +141,21 @@ setuptools.setup(
     url="{}",
     project_urls={},
     classifiers={},
-    packages=["src/"],
+    packages=["{}"],
     python_requires=">={}",
     install_requires = {},
-)    
-        '''.format(n, author, author_email, description, url, project_urls, classifiers, python_requires, install_requires))
-        self.createDir('./'+d+'/'+'src/')
+    entry_points={}
+        '''.format(n, author, author_email, description, url, project_urls, classifiers, d, python_requires, install_requires, entry_points)
+        if new:
+            for i in new:
+                for x in i:
+                    setup = setup + x[0]+'='+x[1]
+        setup = setup+')'
+
+        self.createFile('./'+d+'/', 'setup.py', setup)
+        self.createDir('./'+d+'/'+d)
         print('INFO[004] create the src dir')
-        self.createFile('./'+d+'/'+'src/', '__init__.py', '# your python file')
+        self.createFile('./'+d+'/'+d, '__init__.py', '# your python file')
         print('INFO[005] create the __init__.py file')
         print(f'{n} is success')
 
@@ -150,8 +163,52 @@ setuptools.setup(
         name = dirName
         if name[len(name)-1] != '/':
             raise NameNotSpecificationError(dirName)
-        os.makedirs(name)
+        while True:
+            try:
+                os.makedirs(name)
+                break
+            except Exception as e:
+                while True:
+                    inp = input(
+                        '文件已存在，是否删除？\nThe file already exists. Do you want to delete it? (y/N) ')
+                    if inp == 'y':
+                        shutil.rmtree(name[2:])
+                        break
+                    elif inp == 'N':
+                        quit(repr(e))
+                    else:
+                        continue
 
     def createFile(self, path, name, value):
         with open(path+name, 'w')as f:
             f.write(value)
+
+
+create((('index', '"i"'),),     path='./',
+       dirName='qtscompile/',
+       pkgName='qtscompile',
+       author='xiongtianshuo',
+       author_email='Mr_Xiongts@163.com',
+       description='.',
+       url='https://github.com/seoul2k/qtscompile',
+       project_urls={
+    "Bug Tracker": "https://github.com/seoul2k/qtscompile/issues",
+},
+    classifiers=[
+        'Development Status :: 4 - Beta',
+        'Operating System :: OS Independent',
+        'Intended Audience :: Developers',
+        'License :: OSI Approved :: BSD License',
+        'Programming Language :: Python',
+        'Programming Language :: Python :: Implementation',
+        'Programming Language :: Python :: 2',
+        'Programming Language :: Python :: 2.7',
+        'Programming Language :: Python :: 3',
+        'Programming Language :: Python :: 3.4',
+        'Programming Language :: Python :: 3.5',
+        'Programming Language :: Python :: 3.6',
+        'Programming Language :: Python :: 3.8',
+        'Topic :: Software Development :: Libraries'
+],
+    python_requires=2,
+    install_requires=[""])
